@@ -151,29 +151,31 @@ class PexipNode(PexipClient):
         print(f"Successfully created configuration for {self.args.hostname}")
         self._provision(response.content)
 
-    def _provision(self, content):
+    def _provision(self, content, hostname=None):
+        # Set hostname if not passed
+        if not hostname:
+            hostname = self.args.hostname
+
         start_time = time.time()
         try:
-            print(f"Attempting to provision the node {self.args.hostname}")
+            # Supress warnings, we realize this is a self-signed certificate.
+            requests.packages.urllib3.disable_warnings()
+            print(f"Attempting to provision the node {hostname}")
             # Send request, wait up to 5s (timeout=5) for a response.
             # NOTE: This will not wait the full 5s if the host response with an error after, 2 seconds
             # NOTE: This is a freshly stood up node, it will have a self-signed certificate. Verify MUST be false.
             response = requests_retry_session().post(
-                f"https://{self.args.private_ip}:8443/configuration/bootstrap",
+                f"https://{hostname}:8443/configuration/bootstrap",
                 verify=False,
                 headers={"Content-Type": "text/xml"},
                 data=content,
                 timeout=5,
             )
         except ConnectTimeout as e:
-            print(
-                f"Connection timed out when attempting to provision node: {self.args.hostname}. Error: {e}"
-            )
+            print(f"Connection timed out when attempting to provision node: {hostname}. Error: {e}")
             self._error_and_write_xml(content)
         except Exception as e:
-            print(
-                f"Unknown error when attempting to provision node: {self.args.hostname}. Error: {e}"
-            )
+            print(f"Unknown error when attempting to provision node: {hostname}. Error: {e}")
             self._error_and_write_xml(content)
         else:
             if response.ok:
@@ -192,6 +194,40 @@ class PexipNode(PexipClient):
             print(f"Writing {self.args.hostname}.xml config to disk for retry.")
             xml_file.write(content)
 
+        sys.exit(1)
+
+
+# TODO: Merge this into PexipNode._provision for DRY.
+def provision(content, hostname):
+
+    start_time = time.time()
+    try:
+        print(f"Attempting to provision the node {hostname}")
+        # Send request, wait up to 5s (timeout=5) for a response.
+        # NOTE: This will not wait the full 5s if the host response with an error after, 2 seconds
+        # NOTE: This is a freshly stood up node, it will have a self-signed certificate. Verify MUST be false.
+        response = requests_retry_session().post(
+            f"https://{hostname}:8443/configuration/bootstrap",
+            verify=False,
+            headers={"Content-Type": "text/xml"},
+            data=content,
+            timeout=5,
+        )
+    except ConnectTimeout as e:
+        print(f"Connection timed out when attempting to provision node: {hostname}. Error: {e}")
+    except Exception as e:
+        print(f"Unknown error when attempting to provision node: {hostname}. Error: {e}")
+    else:
+        if response.ok:
+            print(f"Success: {response.status_code} status code.")
+        else:
+            print(
+                f"Error in response returned when provisioning node. Status code: {response.status_code}. Response Content: {response.content}."
+            )
+    finally:
+        end_time = time.time()
+        print(f"Total time {end_time - start_time}")
+
 
 class PexipManager(PexipConnection):
     """Class for controlling the Pexip Manager configuration.  """
